@@ -15,11 +15,11 @@ Business::OnlinePayment::Braintree - Online payment processing through Braintree
 
 =head1 VERSION
 
-Version 0.006
+Version 0.010
 
 =cut
 
-our $VERSION = '0.006';
+our $VERSION = '0.010';
 
 =head1 SYNOPSIS
 
@@ -87,6 +87,9 @@ sub submit {
     elsif ($action eq 'authorization only') {
         $result = $self->sale(0);
     }
+    elsif ($action eq 'post authorization') {
+        $result = Net::Braintree::Transaction->submit_for_settlement($content{order_number}, $content{amount});
+    }
     elsif ($action eq 'credit' ) {
         $result = Net::Braintree::Transaction->refund($content{order_number}, $content{amount});
     }
@@ -268,6 +271,10 @@ Pass cvv to Braintree.
 
 =back
 
+Evan Brown (GH #7):
+
+Add support for post authorization action.
+
 =head1 LICENSE AND COPYRIGHT
 
 Copyright 2011-2014 Stefan Hornburg (Racke).
